# jessicalexander-sort

This package is an exercise pypi package that cobtains multiple sorting method

## In this README :point_down:

- [Features](#features)
- [Usage](#usage)       
  - [Installation](#installation)
  - [Initial setup](#initial-setup)
  - [Example Usage](#example-usage)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)

## Features
- Various sorting algorithms:
  - Bubble Sort
  - Quick Sort
  - Insertion Sort
- Can be used to sort a list of number in ascending format
- Suitable for educational purpose

## Usage

### Installation
You can install the package using pip:

```sh
pip install jessicalexander-sort
```
### Initial setup

1. Make sure you're running at least python 3 and above
2. Prepare the list of numbers you want to sort

### Example Usage
```python
arr = [5,6,7,13,44,67,22,11]

print(sort.bubble_sort.bubble_sort(arr)) #for bubble sort
print(sort.insertion_sort.insertion_sort(arr)) #for insertion sort
print(sort.quick_sort.quick_sort(arr)) #for quick sort
```
## Contributing

If you find a bug :bug:, please open an [issue](https://github.com/jessicalexander/siwp2005_jessicalexander_sort/issues).
If you have an idea for an improvement or new feature :rocket:, please open a [feature request](https://github.com/jessicalexander/siwp2005_jessicalexander_sort/issues).

## License
This project is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.

## Contact
f you have any questions or issues, please open an issue on the [GitHub repository](https://github.com/jessicalexander/siwp2005_jessicalexander_sort/issues) or contact me at [ssicalexander@gmail.com](ssicalexander@gmail.com).